==> puma_pay-3.0.3.tar.gz: lib/redux/pumaPayReducer.dart <==
import 'package:built_collection/built_collection.dart';
import 'package:puma_core/extensions/extList.dart';
import 'package:puma_pay/entities/product/product.dart';
import 'package:puma_pay/redux/pumaPayActions.dart';
import 'package:puma_pay/redux/pumaPayState.dart';
import 'package:redux/redux.dart';

final pumaPayReducer = combineReducers<PumaPayState>([
  TypedReducer<PumaPayState, InitPayAction>(_initPayAction),
  TypedReducer<PumaPayState, GetProductsAction>(_getProductsAction),
  TypedReducer<PumaPayState, GetProductsSuccessAction>(
      _getProductsSuccessAction),
  TypedReducer<PumaPayState, IsStoreAvailableSuccessAction>(
      _isStoreAvailableSuccessAction),
  TypedReducer<PumaPayState, SetPurchasePendingAction>(
      _setPurchasePendingAction),
  TypedReducer<PumaPayState, SetStoreAvailableAction>(_setStoreAvailableAction),
  TypedReducer<PumaPayState, SetRestoringPurchaseAction>(
      _setRestoringPurchaseAction),
  TypedReducer<PumaPayState, VerifyInAppPurchaseAction>(
      _verifyInAppPurchaseAction),
  TypedReducer<PumaPayState, VerifyInAppPurchaseSuccessAction>(
      _verifyInAppPurchaseSuccessAction),
  TypedReducer<PumaPayState, VerifyInAppPurchaseErrorAction>(
      _verifyInAppPurchaseErrorAction),
  TypedReducer<PumaPayState, RestorePurchaseAction>(_restorePurchaseAction),
]);

PumaPayState _initPayAction(PumaPayState state, InitPayAction action) {
  return state.rebuild((b) => b
    ..productIDs = action.productIDs!.toListBuilder()
    ..appleAppStorePassword = action.appleAppStorePassword
    ..verifyEndpoint = action.verifyEndpoint
    ..appStoreSandbox = action.appStoreSandbox);
}

PumaPayState _getProductsAction(PumaPayState state, GetProductsAction action) {
  return state.rebuild((b) => b..productsLoading = true);
}

PumaPayState _getProductsSuccessAction(
    PumaPayState state, GetProductsSuccessAction action) {
  return state.rebuild((b) => b
    ..productsLoading = false
    ..products = action.products!.toListBuilder());
}

PumaPayState _isStoreAvailableSuccessAction(
    PumaPayState state, IsStoreAvailableSuccessAction action) {
  return state.rebuild((b) => b..storeAvailable = action.available);
}

PumaPayState _setPurchasePendingAction(
    PumaPayState state, SetPurchasePendingAction action) {
  return state.rebuild((b) => b..purchasePending = action.purchasePending);
}

PumaPayState _setStoreAvailableAction(
    PumaPayState state, SetStoreAvailableAction action) {
  return state.rebuild((b) => b..storeAvailable = action.storeAvailable);
}

PumaPayState _setRestoringPurchaseAction(
    PumaPayState state, SetRestoringPurchaseAction action) {
  return state.rebuild((b) => b..restoringPurchase = action.restoringPurchase);
}

PumaPayState _verifyInAppPurchaseAction(
    PumaPayState state, VerifyInAppPurchaseAction action) {
  final product = state.products.where((p) => p.id == action.productID).first;
  final productIndex = state.products.indexOf(product);
  final productBuilder = product.toBuilder();

  productBuilder.purchaseDetails.add(action.purchaseDetail);

  return state
      .rebuild((b) => b.products[productIndex] = productBuilder.build());
}

PumaPayState _verifyInAppPurchaseSuccessAction(
    PumaPayState state, VerifyInAppPurchaseSuccessAction action) {
  final product = state.products.where((p) => p.id == action.productID).first;
  final productIndex = state.products.indexOf(product);
  final productBuilder = product.toBuilder();

  productBuilder.purchaseDetails
      .removeWhere((p) => p.purchaseID == action.purchaseDetail.purchaseID);

  productBuilder.purchaseDetails.add(
      action.purchaseDetail.rebuild((pd) => pd.valid = action.valid ?? true));

  return state
      .rebuild((b) => b.products[productIndex] = productBuilder.build());
}

PumaPayState _verifyInAppPurchaseErrorAction(
    PumaPayState state, VerifyInAppPurchaseErrorAction action) {
  final product = state.products.where((p) => p.id == action.productID).first;
  final productIndex = state.products.indexOf(product);
  final productBuilder = product.toBuilder();

  productBuilder.purchaseDetails
      .removeWhere((p) => p.purchaseID == action.purchaseDetail.purchaseID);

  productBuilder.purchaseDetails
      .add(action.purchaseDetail.rebuild((pd) => pd.valid = false));

  return state
      .rebuild((b) => b.products[productIndex] = productBuilder.build());
}

PumaPayState _restorePurchaseAction(
    PumaPayState state, RestorePurchaseAction action) {
  final productsBuilder = ListBuilder<Product>();

  for (var product in state.products) {
    final productBuilder = product.toBuilder();
    productBuilder.purchaseDetails.clear();
    productsBuilder.add(productBuilder.build());
  }
  return state.rebuild((b) => b.products = productsBuilder);
}

==> puma_pay-3.0.10.tar.gz: lib/redux/pumaPayReducer.dart <==
import 'package:built_collection/built_collection.dart';
import 'package:puma_core/extensions/extList.dart';
import 'package:puma_pay/entities/product/product.dart';
import 'package:puma_pay/redux/pumaPayActions.dart';
import 'package:puma_pay/redux/pumaPayState.dart';
import 'package:redux/redux.dart';

final pumaPayReducer = combineReducers<PumaPayState>([
  TypedReducer<PumaPayState, InitPayAction>(_initPayAction),
  TypedReducer<PumaPayState, GetProductsAction>(_getProductsAction),
  TypedReducer<PumaPayState, GetProductsSuccessAction>(
      _getProductsSuccessAction),
  TypedReducer<PumaPayState, IsStoreAvailableSuccessAction>(
      _isStoreAvailableSuccessAction),
  TypedReducer<PumaPayState, SetPurchasePendingAction>(
      _setPurchasePendingAction),
  TypedReducer<PumaPayState, SetStoreAvailableAction>(_setStoreAvailableAction),
  TypedReducer<PumaPayState, SetRestoringPurchaseAction>(
      _setRestoringPurchaseAction),
  TypedReducer<PumaPayState, VerifyInAppPurchaseAction>(
      _verifyInAppPurchaseAction),
  TypedReducer<PumaPayState, VerifyInAppPurchaseSuccessAction>(
      _verifyInAppPurchaseSuccessAction),
  TypedReducer<PumaPayState, VerifyInAppPurchaseErrorAction>(
      _verifyInAppPurchaseErrorAction),
  TypedReducer<PumaPayState, RestorePurchaseAction>(_restorePurchaseAction),
]);

PumaPayState _initPayAction(PumaPayState state, InitPayAction action) {
  return state.rebuild(
    (b) => b
      ..productIDs = action.productIDs!.toListBuilder()
      ..appleAppStorePassword = action.appleAppStorePassword
      ..verifyEndpoint = action.verifyEndpoint,
  );
}

PumaPayState _getProductsAction(PumaPayState state, GetProductsAction action) {
  return state.rebuild((b) => b..productsLoading = true);
}

PumaPayState _getProductsSuccessAction(
    PumaPayState state, GetProductsSuccessAction action) {
  return state.rebuild((b) => b
    ..productsLoading = false
    ..products = action.products!.toListBuilder());
}

PumaPayState _isStoreAvailableSuccessAction(
    PumaPayState state, IsStoreAvailableSuccessAction action) {
  return state.rebuild((b) => b..storeAvailable = action.available);
}

PumaPayState _setPurchasePendingAction(
    PumaPayState state, SetPurchasePendingAction action) {
  return state.rebuild((b) => b..purchasePending = action.purchasePending);
}

PumaPayState _setStoreAvailableAction(
    PumaPayState state, SetStoreAvailableAction action) {
  return state.rebuild((b) => b..storeAvailable = action.storeAvailable);
}

PumaPayState _setRestoringPurchaseAction(
    PumaPayState state, SetRestoringPurchaseAction action) {
  return state.rebuild((b) => b..restoringPurchase = action.restoringPurchase);
}

PumaPayState _verifyInAppPurchaseAction(
    PumaPayState state, VerifyInAppPurchaseAction action) {
  final product = state.products.where((p) => p.id == action.productID).first;
  final productIndex = state.products.indexOf(product);
  final productBuilder = product.toBuilder();

  productBuilder.purchaseDetails.add(action.purchaseDetail);

  return state
      .rebuild((b) => b.products[productIndex] = productBuilder.build());
}

PumaPayState _verifyInAppPurchaseSuccessAction(
    PumaPayState state, VerifyInAppPurchaseSuccessAction action) {
  final product = state.products.where((p) => p.id == action.productID).first;
  final productIndex = state.products.indexOf(product);
  final productBuilder = product.toBuilder();

  productBuilder.purchaseDetails
      .removeWhere((p) => p.purchaseID == action.purchaseDetail.purchaseID);

  productBuilder.purchaseDetails.add(
      action.purchaseDetail.rebuild((pd) => pd.valid = action.valid ?? true));

  return state
      .rebuild((b) => b.products[productIndex] = productBuilder.build());
}

PumaPayState _verifyInAppPurchaseErrorAction(
    PumaPayState state, VerifyInAppPurchaseErrorAction action) {
  final product = state.products.where((p) => p.id == action.productID).first;
  final productIndex = state.products.indexOf(product);
  final productBuilder = product.toBuilder();

  productBuilder.purchaseDetails
      .removeWhere((p) => p.purchaseID == action.purchaseDetail.purchaseID);

  productBuilder.purchaseDetails
      .add(action.purchaseDetail.rebuild((pd) => pd.valid = false));

  return state
      .rebuild((b) => b.products[productIndex] = productBuilder.build());
}

PumaPayState _restorePurchaseAction(
    PumaPayState state, RestorePurchaseAction action) {
  final productsBuilder = ListBuilder<Product>();

  for (var product in state.products) {
    final productBuilder = product.toBuilder();
    productBuilder.purchaseDetails.clear();
    productsBuilder.add(productBuilder.build());
  }
  return state.rebuild((b) => b.products = productsBuilder);
}
